
Selkie
======

Selkie is a Python library for natural language processing and digital
language description.

.. note::

   This project is under active development.

Contents
--------

.. toctree::
   :maxdepth: 2
   :titlesonly:

   intro
   pyext/index
   corpus/rom

Credits
-------
